@@ -1,13 +1,13 @@
-# Copyrights 2011-2012 by [Mark Overmeer].
+# Copyrights 2011-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use warnings;
 use strict;
 
 package XML::Compile::C14N::Util;
 use vars '$VERSION';
-$VERSION = '0.91';
+$VERSION = '0.92';
 
 use base 'Exporter';
 
@@ -21,12 +21,18 @@ my @c14n = qw/
   C14N_EXC_NS
  /;
 
+my @paths = qw/
+  C14N10
+  C14N11
+  C14NEXC  
+ /;
+
 our @EXPORT      = qw/C14N_EXC_NS/;
-our @EXPORT_OK   = (@c14n);
-our %EXPORT_TAGS = (c14n => \@c14n);
+our @EXPORT_OK   = (@c14n, @paths);
+our %EXPORT_TAGS = (c14n => \@c14n, paths => \@paths);
 
 
-# Path components, not exported
+# Path components
 use constant
   { C14N10   => 'http://www.w3.org/TR/2001/REC-xml-c14n-20010315'
   , C14N11   => 'http://www.w3.org/2006/12/xml-c14n11'
